@@ -41,7 +41,8 @@ class AvatarWidget(FileInput):
         context = {}
         context['name'] = name
         context['config'] = config
-        context['avatar_url'] = value.url
+
+        context['avatar_url'] = value.url if value else '/static/awesome_avatar/default.png'
         context['id'] = attrs.get('id', 'id_' + name)
         # todo fix HACK
         context['STATIC_URL'] = settings.STATIC_URL
